/****************************************************************************
 * NCSA HDF                                                                 *
 * Software Development Group                                               *
 * National Center for Supercomputing Applications                          *
 * University of Illinois at Urbana-Champaign                               *
 * 605 E. Springfield, Champaign IL 61820                                   *
 *                                                                          *
 * For conditions of distribution and use, see the accompanying             *
 * hdf/COPYING file.                                                        *
 *                                                                          *
 ****************************************************************************/

/* $Id: tproto.h,v 1.28 2005/01/16 21:44:11 mcgrath Exp $ */

#ifndef _TPROTO_H
#define _TPROTO_H

#include "hdf.h"
#include "tutils.h"

void        test_an(void);
void        test_an_2(void);
void        test_anfile(void);
void        test_man(void);
void        test_hblocks(void);
void        test_hextelt(void);
void        test_hfile(void);
void        test_hfile1(void);
void        test_r24(void);
void        test_r8(void);
void        test_pal(void);
void        test_sdmms(void);
void        test_sdnmms(void);
void        test_tsdstr(void);
void        test_vers(void);
void        test_slab(void);
void        test_litend(void);
void        test_vsets(void);
void        test_vset_attr(void);
void        test_vspack(void);
void        test_comp(void);
void        test_bitio(void);
void        test_tbbt(void);
void        test_macros(void);
void        test_conv(void);
void        test_nbit(void);
void        test_mgr(void);
void        test_bitvect(void);
void        test_chunks(void);
void        test_buffer(void);

#endif /* _TPROTO_H */
